<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="cs_CZ">
<context>
    <name>AboutDialog</name>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Zavřít</translation>
    </message>
</context>
<context>
    <name>AboutLabel</name>
    <message>
        <source>Warning</source>
        <translation>Varování</translation>
    </message>
    <message>
        <source>Unable to launch external application.
</source>
        <translation>Chyba při spouštění vnější aplikace.
</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>Assistant</name>
    <message>
        <source>Error registering documentation file &apos;%1&apos;: %2</source>
        <translation>Chyba při záznamu souboru s dokumentací &apos;%1&apos;: %2</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation>Chyba: %1</translation>
    </message>
    <message>
        <source>Could not register documentation file
%1

Reason:
%2</source>
        <translation>Soubor s dokumentací %1 nelze zaznamenat

Důvod:
%2</translation>
    </message>
    <message>
        <source>Documentation successfully registered.</source>
        <translation>Dokumentace byla úspěšně zaznamenána.</translation>
    </message>
    <message>
        <source>Could not unregister documentation file
%1

Reason:
%2</source>
        <translation>Zaznamenání souboru s dokumentací %1 nelze zrušit

Grund:
%2</translation>
    </message>
    <message>
        <source>Documentation successfully unregistered.</source>
        <translation>Dokumentace byla úspěšně odstraněna.</translation>
    </message>
    <message>
        <source>Error reading collection file &apos;%1&apos;: %2.</source>
        <translation>Chyba při čtení sbírkového souboru &apos;%1&apos;: %2.</translation>
    </message>
    <message>
        <source>Error creating collection file &apos;%1&apos;: %2.</source>
        <translation>Chyba při vytváření sbírkového souboru &apos;%1&apos;: %2.</translation>
    </message>
    <message>
        <source>Cannot load sqlite database driver!</source>
        <translation>Databázový ovladač pro SQLite nelze nahrát!</translation>
    </message>
</context>
<context>
    <name>BookmarkDialog</name>
    <message>
        <source>Add Bookmark</source>
        <translation>Přidat záložku</translation>
    </message>
    <message>
        <source>Bookmark:</source>
        <translation>Záložka:</translation>
    </message>
    <message>
        <source>Add in Folder:</source>
        <translation>Zřídit ve složce:</translation>
    </message>
    <message>
        <source>New Folder</source>
        <translation>Nová složka</translation>
    </message>
    <message>
        <source>Bookmarks</source>
        <translation type="obsolete">Záložky</translation>
    </message>
    <message>
        <source>+</source>
        <translation>+</translation>
    </message>
    <message>
        <source>Delete Folder</source>
        <translation type="obsolete">Smazat složku</translation>
    </message>
    <message>
        <source>Rename Folder</source>
        <translation>Přejmenovat složku</translation>
    </message>
</context>
<context>
    <name>BookmarkItem</name>
    <message>
        <source>New Folder</source>
        <translation>Nová složka</translation>
    </message>
    <message>
        <source>Untitled</source>
        <translation>Bez názvu</translation>
    </message>
</context>
<context>
    <name>BookmarkManager</name>
    <message>
        <source>Bookmarks</source>
        <translation type="obsolete">Záložky</translation>
    </message>
    <message>
        <source>Untitled</source>
        <translation>Bez názvu</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Odstranit</translation>
    </message>
    <message>
        <source>You are going to delete a Folder, this will also&lt;br&gt;remove it&apos;s content. Are you sure to continue?</source>
        <translation>Když smažete tuto složku, bude smazán i &lt;br&gt;celý její obsah. Opravdu chcete pokračovat?</translation>
    </message>
    <message>
        <source>Manage Bookmarks...</source>
        <translation>Spravovat záložky...</translation>
    </message>
    <message>
        <source>Add Bookmark...</source>
        <translation>Přidat záložku...</translation>
    </message>
    <message>
        <source>Ctrl+D</source>
        <translation>Ctrl+D</translation>
    </message>
    <message>
        <source>Delete Folder</source>
        <translation>Smazat složku</translation>
    </message>
    <message>
        <source>Rename Folder</source>
        <translation>Přejmenovat složku</translation>
    </message>
    <message>
        <source>Show Bookmark</source>
        <translation>Ukázat záložku</translation>
    </message>
    <message>
        <source>Show Bookmark in New Tab</source>
        <translation>Ukázat záložku v nové kartě</translation>
    </message>
    <message>
        <source>Delete Bookmark</source>
        <translation>Smazat záložku</translation>
    </message>
    <message>
        <source>Rename Bookmark</source>
        <translation>Přejmenovat záložku</translation>
    </message>
    <message>
        <source>New Folder</source>
        <translation type="obsolete">Nová složka</translation>
    </message>
</context>
<context>
    <name>BookmarkManagerWidget</name>
    <message>
        <source>Manage Bookmarks</source>
        <translation>Spravovat záložky</translation>
    </message>
    <message>
        <source>Search:</source>
        <translation>Hledat:</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Odstranit</translation>
    </message>
    <message>
        <source>Import and Backup</source>
        <translation>Zavést a zazálohovat</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Import...</source>
        <translation>Zavést...</translation>
    </message>
    <message>
        <source>Export...</source>
        <translation>Vyvést...</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>Otevřít soubor</translation>
    </message>
    <message>
        <source>Files (*.xbel)</source>
        <translation>Soubory XBEL (*.xbel)</translation>
    </message>
    <message>
        <source>Save File</source>
        <translation>Uložit soubor</translation>
    </message>
    <message>
        <source>Qt Assistant</source>
        <translation>Qt Assistant</translation>
    </message>
    <message>
        <source>Unable to save bookmarks.</source>
        <translation>Nelze uložit záložky.</translation>
    </message>
    <message>
        <source>You are goingto delete a Folder, this will also&lt;br&gt; remove it&apos;s content. Are you sure to continue?</source>
        <translation>Chystáte se smazat složku, což &lt;br&gt; odstraní i její obsah. Jste si jistý, že chcete pokračovat?</translation>
    </message>
    <message>
        <source>Delete Folder</source>
        <translation>Smazat složku</translation>
    </message>
    <message>
        <source>Rename Folder</source>
        <translation>Přejmenovat složku</translation>
    </message>
    <message>
        <source>Show Bookmark</source>
        <translation>Ukázat záložku</translation>
    </message>
    <message>
        <source>Show Bookmark in New Tab</source>
        <translation>Ukázat záložku v nové kartě</translation>
    </message>
    <message>
        <source>Delete Bookmark</source>
        <translation>Smazat záložku</translation>
    </message>
    <message>
        <source>Rename Bookmark</source>
        <translation>Přejmenovat záložku</translation>
    </message>
</context>
<context>
    <name>BookmarkModel</name>
    <message>
        <source>Name</source>
        <translation>Název</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Adresa</translation>
    </message>
    <message>
        <source>Toolbar Menu</source>
        <translation>Nabídka nástrojového pruhu</translation>
    </message>
    <message>
        <source>Bookmarks Menu</source>
        <translation>Nabídka se záložkami</translation>
    </message>
</context>
<context>
    <name>BookmarkWidget</name>
    <message>
        <source>Filter:</source>
        <translation>Filtr:</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Odstranit</translation>
    </message>
    <message>
        <source>Delete Folder</source>
        <translation type="obsolete">Smazat složku</translation>
    </message>
    <message>
        <source>Rename Folder</source>
        <translation type="obsolete">Přejmenovat složku</translation>
    </message>
    <message>
        <source>Show Bookmark</source>
        <translation type="obsolete">Ukázat záložku</translation>
    </message>
    <message>
        <source>Show Bookmark in New Tab</source>
        <translation type="obsolete">Ukázat záložku v nové kartě</translation>
    </message>
    <message>
        <source>Delete Bookmark</source>
        <translation type="obsolete">Smazat záložku</translation>
    </message>
    <message>
        <source>Rename Bookmark</source>
        <translation type="obsolete">Přejmenovat záložku</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Přidat</translation>
    </message>
    <message>
        <source>Bookmarks</source>
        <translation>Záložky</translation>
    </message>
</context>
<context>
    <name>CentralWidget</name>
    <message>
        <source>Add new page</source>
        <translation type="obsolete">Přidat novou stranu</translation>
    </message>
    <message>
        <source>Close current page</source>
        <translation type="obsolete">Zavřít současnou stranu</translation>
    </message>
    <message>
        <source>Print Document</source>
        <translation>Vytisknout dokument</translation>
    </message>
    <message>
        <source>unknown</source>
        <translation type="obsolete">Neznámý</translation>
    </message>
    <message>
        <source>Add New Page</source>
        <translation type="obsolete">Přidat novou stranu</translation>
    </message>
    <message>
        <source>Close This Page</source>
        <translation type="obsolete">Zavřít tuto stranu</translation>
    </message>
    <message>
        <source>Close Other Pages</source>
        <translation type="obsolete">Zavřít jiné strany</translation>
    </message>
    <message>
        <source>Add Bookmark for this Page...</source>
        <translation type="obsolete">Přidat záložku pro tuto stranu...</translation>
    </message>
    <message>
        <source>Search</source>
        <translation type="obsolete">Hledat</translation>
    </message>
</context>
<context>
    <name>CmdLineParser</name>
    <message>
        <source>Usage: assistant [Options]

-collectionFile file       Uses the specified collection
                           file instead of the default one
-showUrl url               Shows the document with the
                           url.
-enableRemoteControl       Enables Assistant to be
                           remotely controlled.
-show widget               Shows the specified dockwidget
                           which can be &quot;contents&quot;, &quot;index&quot;,
                           &quot;bookmarks&quot; or &quot;search&quot;.
-activate widget           Activates the specified dockwidget
                           which can be &quot;contents&quot;, &quot;index&quot;,
                           &quot;bookmarks&quot; or &quot;search&quot;.
-hide widget               Hides the specified dockwidget
                           which can be &quot;contents&quot;, &quot;index&quot;
                           &quot;bookmarks&quot; or &quot;search&quot;.
-register helpFile         Registers the specified help file
                           (.qch) in the given collection
                           file.
-unregister helpFile       Unregisters the specified help file
                           (.qch) from the give collection
                           file.
-setCurrentFilter filter   Set the filter as the active filter.
-remove-search-index       Removes the full text search index.
-rebuild-search-index      Re-builds the full text search index (potentially slow).
-quiet                     Does not display any error or
                           status message.
-help                      Displays this help.
</source>
        <translation>Použití: assistant [volby]

-collectionFile file       Použije zadaný soubor se sbírkou
                           namísto výchozího souboru
-showUrl url               Ukáže dokument s adresou
                           (URL).
-enableRemoteControl       Povolí, aby byl Assistant
                           ovládán vzdáleně.
-show widget               Ukáže zadaný panelový prvek,
                           což může být &quot;obsah&quot;, &quot;rejstřík&quot;,
                           &quot;záložky&quot; nebo &quot;hledání&quot;.
-activate widget           Zapne zadaný panelový prvek,
                           což může být &quot;obsah&quot;, &quot;rejstřík&quot;,
                           &quot;záložky&quot; nebo &quot;hledání&quot;.
-hide widget               Skryje zadaný panelový prvek,
                           což může být &quot;obsah&quot;, &quot;rejstřík&quot;,
                           &quot;záložky&quot; nebo &quot;hledání&quot;.
-register helpFile         Registers the specified help file
                           (.qch) in the given collection
                           file.
-unregister helpFile       Odregistruje zadaný soubor s nápovědou
                           (.qch) ze souboru se sbírkou.
-setCurrentFilter filter   Nastaví filtr jako aktivní filtr.
-remove-search-index       Odstraní rejstřík hledání v celém textu.
-rebuild-search-index      Přestaví rejstřík hledání v celém textu (může to být pomalé).
-quiet                     Nezobrazí žádnou chybu nebo
                           zprávu o stavu.
-help                      Zobrazí tuto nápovědu.
</translation>
    </message>
    <message>
        <source>Unknown option: %1</source>
        <translation>Neznámá volba: %1</translation>
    </message>
    <message>
        <source>The collection file &apos;%1&apos; does not exist.</source>
        <translation>Sbírkový soubor &apos;%1&apos; neexistuje.</translation>
    </message>
    <message>
        <source>Missing collection file.</source>
        <translation>Chybí sbírkový soubor.</translation>
    </message>
    <message>
        <source>Invalid URL &apos;%1&apos;.</source>
        <translation>Neplatná adresa (URL) &apos;%1&apos;.</translation>
    </message>
    <message>
        <source>Missing URL.</source>
        <translation>Chybí adresa (URL).</translation>
    </message>
    <message>
        <source>Unknown widget: %1</source>
        <translation>Neznámý prvek: %1</translation>
    </message>
    <message>
        <source>Missing widget.</source>
        <translation>Chybí prvek.</translation>
    </message>
    <message>
        <source>The Qt help file &apos;%1&apos; does not exist.</source>
        <translation>Soubor s nápovědou ke Qt &apos;%1&apos; nelze najít.</translation>
    </message>
    <message>
        <source>Missing help file.</source>
        <translation>Chybí soubor s nápovědou.</translation>
    </message>
    <message>
        <source>Missing filter argument.</source>
        <translation>Chybí argument pro filtr.</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Chyba</translation>
    </message>
    <message>
        <source>Notice</source>
        <translation>Zpráva</translation>
    </message>
</context>
<context>
    <name>ContentWindow</name>
    <message>
        <source>Open Link</source>
        <translation>Otevřít adresu odkazu</translation>
    </message>
    <message>
        <source>Open Link in New Tab</source>
        <translation>Otevřít odkaz v nové kartě</translation>
    </message>
</context>
<context>
    <name>ConversionWizard</name>
    <message>
        <source>Help Conversion Wizard</source>
        <translation>Průvodce pro převod nápovědy</translation>
    </message>
    <message>
        <source>Converting %1...</source>
        <translation>Převádí se %1...</translation>
    </message>
    <message>
        <source>Writing help collection file...</source>
        <translation>Zapisuje se soubor se sbírkou s nápovědou...</translation>
    </message>
    <message>
        <source>Done.</source>
        <translation>Hotovo.</translation>
    </message>
</context>
<context>
    <name>FilesPage</name>
    <message>
        <source>Form</source>
        <translation>Formulář</translation>
    </message>
    <message>
        <source>Files:</source>
        <translation>Soubory:</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Odstranit</translation>
    </message>
    <message>
        <source>Remove All</source>
        <translation>Odstranit vše</translation>
    </message>
    <message>
        <source>Unreferenced Files</source>
        <translation>Neodkazované soubory</translation>
    </message>
    <message>
        <source>Remove files which are neither referenced by a keyword nor by the TOC.</source>
        <translation>Odstranit soubory, které nejsou odkazovány ani klíčovým slovem ani obsahem (TOC).</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;b&gt;Warning:&lt;/b&gt; When removing images or stylesheets, be aware that those files are not directly referenced by the .adp or .dcf file.&lt;/p&gt;</source>
        <translation>&lt;p&gt;&lt;b&gt;Varování:&lt;/b&gt; Když odstraňujete obrázky nebo stylové listy, buďte si vědom, že tyto soubory nejsou přímo odkazovány souborem .adp nebo .dcf.&lt;/p&gt;</translation>
    </message>
</context>
<context>
    <name>FilterNameDialogClass</name>
    <message>
        <source>Add Filter Name</source>
        <translation>Přidat název filtru</translation>
    </message>
    <message>
        <source>Filter Name:</source>
        <translation>Název filtru:</translation>
    </message>
</context>
<context>
    <name>FilterPage</name>
    <message>
        <source>Form</source>
        <translation>Formulář</translation>
    </message>
    <message>
        <source>Filter attributes for current documentation (comma separated list):</source>
        <translation>Vlastnosti filtru pro nynější dokumentaci (čárkou oddělený seznam):</translation>
    </message>
    <message>
        <source>Custom Filters</source>
        <translation>Uživatelsky stanovené filtry</translation>
    </message>
    <message>
        <source>1</source>
        <translation>1</translation>
    </message>
    <message>
        <source>2</source>
        <translation>2</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Přidat</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Odstranit</translation>
    </message>
    <message>
        <source>Filter Settings</source>
        <translation>Nastavení filtru</translation>
    </message>
    <message>
        <source>Specify the filter attributes for the documentation. If filter attributes are used, also define a custom filter for it. Both the filter attributes and the custom filters are optional.</source>
        <translation>Zadejte vlastnosti filtru pro dokumentaci. Pokud jsou používány vlastnosti filtru, měl by se pro ně stanovit i uživatelsky stanovený filtr. Jak vlastnosti filtru tak uživatelsky stanovené filtry jsou volitelné.</translation>
    </message>
    <message>
        <source>Filter Name</source>
        <translation>Název filtru</translation>
    </message>
    <message>
        <source>Filter Attributes</source>
        <translation>Vlastnosti filtru</translation>
    </message>
    <message>
        <source>The custom filter &apos;%1&apos; is defined multiple times.</source>
        <translation>Uživatelsky stanovený filtr &apos;%1&apos; je stanoven vícekrát.</translation>
    </message>
    <message>
        <source>The attributes for custom filter &apos;%1&apos; are defined multiple times.</source>
        <translation>Vlastnosti pro uživatelsky stanovený filtr &apos;%1&apos; jsou vymezeny vícekrát.</translation>
    </message>
    <message>
        <source>unfiltered</source>
        <comment>list of available documentation</comment>
        <translation>Nefiltrováno</translation>
    </message>
</context>
<context>
    <name>FindWidget</name>
    <message>
        <source>Previous</source>
        <translation>Předchozí</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Další</translation>
    </message>
    <message>
        <source>Case Sensitive</source>
        <translation>Rozlišující velká a malá písmena</translation>
    </message>
    <message>
        <source>Whole words</source>
        <translation type="obsolete">Celá slova</translation>
    </message>
    <message>
        <source>&lt;img src=&quot;:/trolltech/assistant/images/wrap.png&quot;&gt;&amp;nbsp;Search wrapped</source>
        <translation>&lt;img src=&quot;:/trolltech/assistant/images/wrap.png&quot;&gt;&amp;nbsp;Konec strany</translation>
    </message>
</context>
<context>
    <name>FinishPage</name>
    <message>
        <source>Converting File</source>
        <translation>Převádí se soubor</translation>
    </message>
    <message>
        <source>Creating the new Qt help files from the old ADP file.</source>
        <translation>Vytváří se nové soubory s nápovědou Qt ze starých souborů ADP.</translation>
    </message>
</context>
<context>
    <name>FontPanel</name>
    <message>
        <source>Font</source>
        <translation>Písmo</translation>
    </message>
    <message>
        <source>&amp;Writing system</source>
        <translation>Způsob &amp;psaní</translation>
    </message>
    <message>
        <source>&amp;Family</source>
        <translation>&amp;Písmová rodina</translation>
    </message>
    <message>
        <source>&amp;Style</source>
        <translation>&amp;Styl</translation>
    </message>
    <message>
        <source>&amp;Point size</source>
        <translation>&amp;Bodová velikost</translation>
    </message>
</context>
<context>
    <name>GeneralPage</name>
    <message>
        <source>Form</source>
        <translation>Formulář</translation>
    </message>
    <message>
        <source>Namespace:</source>
        <translation>Jmenný prostor:</translation>
    </message>
    <message>
        <source>Virtual Folder:</source>
        <translation>Virtuální složka:</translation>
    </message>
    <message>
        <source>General Settings</source>
        <translation>Obecná nastavení</translation>
    </message>
    <message>
        <source>Specify the namespace and the virtual folder for the documentation.</source>
        <translation>Zadejte jmenný prostor a virtuální složku pro dokumentaci.</translation>
    </message>
    <message>
        <source>Namespace Error</source>
        <translation>Chyba ve jmenném prostoru</translation>
    </message>
    <message>
        <source>The namespace contains some invalid characters.</source>
        <translation>Jmenný prostor obsahuje nějaké neplatné znaky.</translation>
    </message>
    <message>
        <source>Virtual Folder Error</source>
        <translation>Chyba ve virtuální složce</translation>
    </message>
    <message>
        <source>The virtual folder contains some invalid characters.</source>
        <translation>Virtuální složka obsahuje nějaké neplatné znaky.</translation>
    </message>
</context>
<context>
    <name>GlobalActions</name>
    <message>
        <source>&amp;Back</source>
        <translation>&amp;Zpět</translation>
    </message>
    <message>
        <source>&amp;Forward</source>
        <translation>&amp;Dopředu</translation>
    </message>
    <message>
        <source>&amp;Home</source>
        <translation>&amp;Začáteční strana</translation>
    </message>
    <message>
        <source>ALT+Home</source>
        <translation>ALT+Home</translation>
    </message>
    <message>
        <source>Zoom &amp;in</source>
        <translation>&amp;Přiblížit</translation>
    </message>
    <message>
        <source>Zoom &amp;out</source>
        <translation>&amp;Oddálit</translation>
    </message>
    <message>
        <source>&amp;Copy selected Text</source>
        <translation>&amp;Kopírovat vybraný text</translation>
    </message>
    <message>
        <source>&amp;Print...</source>
        <translation>&amp;Tisk...</translation>
    </message>
    <message>
        <source>&amp;Find in Text...</source>
        <translation>&amp;Najít v textu...</translation>
    </message>
    <message>
        <source>&amp;Find</source>
        <translation>&amp;Najít</translation>
    </message>
</context>
<context>
    <name>HelpEngineWrapper</name>
    <message>
        <source>Unfiltered</source>
        <translation>Nefiltrováno</translation>
    </message>
</context>
<context>
    <name>HelpGenerator</name>
    <message>
        <source>Warning: %1</source>
        <translation>Varování: %1</translation>
    </message>
</context>
<context>
    <name>HelpViewer</name>
    <message>
        <source>Help</source>
        <translation type="obsolete">Nápověda</translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="obsolete">OK</translation>
    </message>
    <message>
        <source>&lt;title&gt;about:blank&lt;/title&gt;</source>
        <translation>&lt;title&gt;about:blank&lt;/title&gt;</translation>
    </message>
    <message>
        <source>&lt;title&gt;Error 404...&lt;/title&gt;&lt;div align=&quot;center&quot;&gt;&lt;br&gt;&lt;br&gt;&lt;h1&gt;The page could not be found&lt;/h1&gt;&lt;br&gt;&lt;h3&gt;&apos;%1&apos;&lt;/h3&gt;&lt;/div&gt;</source>
        <translation>&lt;title&gt;Chyba 404 ...&lt;/title&gt;&lt;div align=&quot;center&quot;&gt;&lt;br&gt;&lt;br&gt;&lt;h1&gt;Stranu se nepodařilo najít.&lt;/h1&gt;&lt;br&gt;&lt;h3&gt;&apos;%1&apos;&lt;/h3&gt;&lt;/div&gt;</translation>
    </message>
    <message>
        <source>Open Link</source>
        <translation>Otevřít adresu odkazu</translation>
    </message>
    <message>
        <source>Copy &amp;Link Location</source>
        <translation>&amp;Kopírovat adresu odkazu</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopírovat</translation>
    </message>
    <message>
        <source>Reload</source>
        <translation>Nahrát znovu</translation>
    </message>
    <message>
        <source>Open Link in New Tab	Ctrl+LMB</source>
        <translation>Otevřít odkaz v nové kartě	Ctrl+LMB</translation>
    </message>
    <message>
        <source>Open Link in New Tab</source>
        <translation type="obsolete">Otevřít odkaz v nové kartě</translation>
    </message>
    <message>
        <source>Unable to launch external application.
</source>
        <translation type="obsolete">Chyba při spouštění vnější aplikace.
</translation>
    </message>
    <message>
        <source>Open Link in New Page</source>
        <translation>Otevřít odkazu na nové straně</translation>
    </message>
</context>
<context>
    <name>HelpWindow</name>
    <message>
        <source>&lt;center&gt;&lt;b&gt;Wizard Assistant&lt;/b&gt;&lt;/center&gt;</source>
        <translation>&lt;center&gt;&lt;b&gt;Průvodce&lt;/b&gt;&lt;/center&gt;</translation>
    </message>
</context>
<context>
    <name>IdentifierPage</name>
    <message>
        <source>Form</source>
        <translation>Formulář</translation>
    </message>
    <message>
        <source>Create identifiers</source>
        <translation>Vytvořit identifikátory</translation>
    </message>
    <message>
        <source>Global prefix:</source>
        <translation>Celková předpona:</translation>
    </message>
    <message>
        <source>Inherit prefix from file names</source>
        <translation>Předponu vzít z názvů souborů</translation>
    </message>
    <message>
        <source>Identifiers</source>
        <translation>Identifikátory</translation>
    </message>
    <message>
        <source>This page allows you to create identifiers from the keywords found in the .adp or .dcf file.</source>
        <translation>Tato stránka vám umožňuje vytvořit identifikátory z klíčových slov nalezených v souboru .adp nebo .dcf.</translation>
    </message>
</context>
<context>
    <name>IndexWindow</name>
    <message>
        <source>&amp;Look for:</source>
        <translation>&amp;Hledat:</translation>
    </message>
    <message>
        <source>Open Link</source>
        <translation>Otevřít adresu odkazu</translation>
    </message>
    <message>
        <source>Open Link in New Tab</source>
        <translation>Otevřít odkaz v nové kartě</translation>
    </message>
</context>
<context>
    <name>InputPage</name>
    <message>
        <source>Form</source>
        <translation>Formulář</translation>
    </message>
    <message>
        <source>File name:</source>
        <translation>Název souboru:</translation>
    </message>
    <message>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <source>Input File</source>
        <translation>Vstupní soubor</translation>
    </message>
    <message>
        <source>Specify the .adp or .dcf file you want to convert to the new Qt help project format and/or collection format.</source>
        <translation>Zadejte soubor .adp nebo .dcf, který chcete převést do nového formátu projektů nápovědy Qt a/nebo formátu sbírky.</translation>
    </message>
    <message>
        <source>Open file</source>
        <translation>Otevřít soubor</translation>
    </message>
    <message>
        <source>Qt Help Files (*.adp *.dcf)</source>
        <translation>Soubory s nápovědou (*.adp *.dcf)</translation>
    </message>
    <message>
        <source>File Open Error</source>
        <translation>Chyba při otevírání souboru</translation>
    </message>
    <message>
        <source>The specified file could not be opened!</source>
        <translation>Zadaný soubor nelze otevřít!</translation>
    </message>
    <message>
        <source>File Parsing Error</source>
        <translation>Chyba při zpracování souboru</translation>
    </message>
    <message>
        <source>Parsing error in line %1!</source>
        <translation>Chyba při zpracování na řádku %1!</translation>
    </message>
</context>
<context>
    <name>InstallDialog</name>
    <message>
        <source>Install Documentation</source>
        <translation>Nainstalovat dokumentaci</translation>
    </message>
    <message>
        <source>Downloading documentation info...</source>
        <translation>Stahuje se informace o  dokumentaci...</translation>
    </message>
    <message>
        <source>Download canceled.</source>
        <translation>Stahování bylo zrušeno.</translation>
    </message>
    <message>
        <source>Done.</source>
        <translation>Hotovo.</translation>
    </message>
    <message>
        <source>The file %1 already exists. Do you want to overwrite it?</source>
        <translation>Soubor %1 již existuje. Chcete jej přepsat?</translation>
    </message>
    <message>
        <source>Unable to save the file %1: %2.</source>
        <translation>Soubor %1 nelze uložit: %2.</translation>
    </message>
    <message>
        <source>Downloading %1...</source>
        <translation>Stahuje se %1...</translation>
    </message>
    <message>
        <source>Download failed: %1.</source>
        <translation>Stažení se nezdařilo: %1.</translation>
    </message>
    <message>
        <source>Documentation info file is corrupt!</source>
        <translation>Soubor s informací o dokumentaci je poškozen!</translation>
    </message>
    <message>
        <source>Download failed: Downloaded file is corrupted.</source>
        <translation>Stažení se nezdařilo: Stažený soubor je pravděpodobně poškozen.</translation>
    </message>
    <message>
        <source>Installing documentation %1...</source>
        <translation>Instaluje dokumentace %1...</translation>
    </message>
    <message>
        <source>Error while installing documentation:
%1</source>
        <translation>Chyba při instalaci dokumentace:
%1</translation>
    </message>
    <message>
        <source>Available Documentation:</source>
        <translation>Dostupná dokumentace:</translation>
    </message>
    <message>
        <source>Install</source>
        <translation>Instalovat</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Zavřít</translation>
    </message>
    <message>
        <source>Installation Path:</source>
        <translation>Cesta pro instalaci:</translation>
    </message>
    <message>
        <source>...</source>
        <translation>...</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Index</source>
        <translation>Rejstřík</translation>
    </message>
    <message>
        <source>Contents</source>
        <translation>Obsah</translation>
    </message>
    <message>
        <source>Bookmarks</source>
        <translation>Záložky</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Hledat</translation>
    </message>
    <message>
        <source>Qt Assistant</source>
        <translation>Qt Assistant</translation>
    </message>
    <message>
        <source>Unfiltered</source>
        <translation type="obsolete">Bez filtru</translation>
    </message>
    <message>
        <source>Page Set&amp;up...</source>
        <translation>&amp;Nastavení strany...</translation>
    </message>
    <message>
        <source>Print Preview...</source>
        <translation>Náhled tisku...</translation>
    </message>
    <message>
        <source>&amp;Print...</source>
        <translation type="obsolete">&amp;Tisk...</translation>
    </message>
    <message>
        <source>New &amp;Tab</source>
        <translation>Nová &amp;karta</translation>
    </message>
    <message>
        <source>&amp;Close Tab</source>
        <translation>&amp;Zavřít kartu</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Ukončit</translation>
    </message>
    <message>
        <source>CTRL+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <source>&amp;Copy selected Text</source>
        <translation type="obsolete">&amp;Kopírovat vybraný text</translation>
    </message>
    <message>
        <source>&amp;Find in Text...</source>
        <translation type="obsolete">&amp;Najít v textu...</translation>
    </message>
    <message>
        <source>&amp;Find</source>
        <translation type="obsolete">&amp;Najít</translation>
    </message>
    <message>
        <source>Find &amp;Next</source>
        <translation>Hledat &amp;dál</translation>
    </message>
    <message>
        <source>Find &amp;Previous</source>
        <translation>Najít &amp;předchozí</translation>
    </message>
    <message>
        <source>Preferences...</source>
        <translation>Nastavení...</translation>
    </message>
    <message>
        <source>Zoom &amp;in</source>
        <translation type="obsolete">&amp;Zvětšit</translation>
    </message>
    <message>
        <source>Zoom &amp;out</source>
        <translation type="obsolete">&amp;Zmenšit</translation>
    </message>
    <message>
        <source>Normal &amp;Size</source>
        <translation>Obvyklá &amp;velikost</translation>
    </message>
    <message>
        <source>Ctrl+0</source>
        <translation>Ctrl+0</translation>
    </message>
    <message>
        <source>ALT+C</source>
        <translation>ALT+C</translation>
    </message>
    <message>
        <source>ALT+I</source>
        <translation>ALT+I</translation>
    </message>
    <message>
        <source>ALT+S</source>
        <translation>ALT+S</translation>
    </message>
    <message>
        <source>&amp;Home</source>
        <translation type="obsolete">&amp;Začáteční strana</translation>
    </message>
    <message>
        <source>&amp;Back</source>
        <translation type="obsolete">&amp;Zpět</translation>
    </message>
    <message>
        <source>&amp;Forward</source>
        <translation type="obsolete">&amp;Dopředu</translation>
    </message>
    <message>
        <source>Sync with Table of Contents</source>
        <translation>Seřídit stranu s kartou obsahu</translation>
    </message>
    <message>
        <source>Sync</source>
        <translation>Seřídit</translation>
    </message>
    <message>
        <source>Next Page</source>
        <translation>Další strana</translation>
    </message>
    <message>
        <source>Ctrl+Alt+Right</source>
        <translation>Ctrl+Alt+Right</translation>
    </message>
    <message>
        <source>Previous Page</source>
        <translation>Předchozí strana</translation>
    </message>
    <message>
        <source>Ctrl+Alt+Left</source>
        <translation>Ctrl+Alt+Left</translation>
    </message>
    <message>
        <source>Could not register file &apos;%1&apos;: %2</source>
        <translation>Nepodařilo se zaznamenat soubor &apos;%1&apos;: %2</translation>
    </message>
    <message>
        <source>Add Bookmark...</source>
        <translation type="obsolete">Přidat záložku...</translation>
    </message>
    <message>
        <source>About...</source>
        <translation>O...</translation>
    </message>
    <message>
        <source>Navigation Toolbar</source>
        <translation>Navigační pruh</translation>
    </message>
    <message>
        <source>Toolbars</source>
        <translation>Nástrojové pruhy</translation>
    </message>
    <message>
        <source>Filter Toolbar</source>
        <translation>Filtrovací pruh</translation>
    </message>
    <message>
        <source>Filtered by:</source>
        <translation>Filtr:</translation>
    </message>
    <message>
        <source>Address Toolbar</source>
        <translation>Adresní pruh</translation>
    </message>
    <message>
        <source>Address:</source>
        <translation>Adresa:</translation>
    </message>
    <message>
        <source>Could not find the associated content item.</source>
        <translation>Nepodařilo se najít příslušnou položku obsahu.</translation>
    </message>
    <message>
        <source>&lt;center&gt;&lt;h3&gt;%1&lt;/h3&gt;&lt;p&gt;Version %2&lt;/p&gt;&lt;/center&gt;&lt;p&gt;Copyright (C) 2012 Nokia Corporation and/or its subsidiary(-ies).&lt;/p&gt;</source>
        <translation>&lt;center&gt;&lt;h3&gt;%1&lt;/h3&gt;&lt;p&gt;Verze %2&lt;/p&gt;&lt;/center&gt;&lt;p&gt;Autorské právo (C) 2012 Nokia Corporation a/nebo její dceřinná společnost(i).&lt;/p&gt;</translation>
    </message>
    <message>
        <source>About %1</source>
        <translation>O %1</translation>
    </message>
    <message>
        <source>Updating search index</source>
        <translation>Sestavuje se rejstřík hledání</translation>
    </message>
    <message>
        <source>Looking for Qt Documentation...</source>
        <translation>Hledá se dokumentace ke Qt...</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;Okno</translation>
    </message>
    <message>
        <source>Minimize</source>
        <translation>Zmenšit</translation>
    </message>
    <message>
        <source>Ctrl+M</source>
        <translation>Ctrl+M</translation>
    </message>
    <message>
        <source>Zoom</source>
        <translation>Zvětšení</translation>
    </message>
    <message>
        <source>Open Pages</source>
        <translation>Otevřít strany</translation>
    </message>
    <message>
        <source>Bookmark Toolbar</source>
        <translation>Nástrojový pruh záložek</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Soubor</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>&amp;Ukončit</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Úpravy</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Pohled</translation>
    </message>
    <message>
        <source>ALT+P</source>
        <translation>ALT+P</translation>
    </message>
    <message>
        <source>&amp;Go</source>
        <translation>&amp;Jít na</translation>
    </message>
    <message>
        <source>ALT+Home</source>
        <translation type="obsolete">ALT+Home</translation>
    </message>
    <message>
        <source>&amp;Bookmarks</source>
        <translation>&amp;Záložky</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Nápověda</translation>
    </message>
    <message>
        <source>ALT+O</source>
        <translation>ALT+O</translation>
    </message>
    <message>
        <source>CTRL+D</source>
        <translation type="obsolete">CTRL+D</translation>
    </message>
</context>
<context>
    <name>OpenPagesWidget</name>
    <message>
        <source>Close %1</source>
        <translation>Zavřít %1</translation>
    </message>
    <message>
        <source>Close All Except %1</source>
        <translation>Zavřít vše kromě %1</translation>
    </message>
</context>
<context>
    <name>OutputPage</name>
    <message>
        <source>Form</source>
        <translation>Formulář</translation>
    </message>
    <message>
        <source>Project file name:</source>
        <translation>Název projektového souboru:</translation>
    </message>
    <message>
        <source>Collection file name:</source>
        <translation>Název sbírkového souboru:</translation>
    </message>
    <message>
        <source>Output File Names</source>
        <translation>Názvy výstupních souborů</translation>
    </message>
    <message>
        <source>Specify the file names for the output files.</source>
        <translation>Zadejte názvy souborů pro výstupní soubory.</translation>
    </message>
    <message>
        <source>Convert...</source>
        <translation>Převést...</translation>
    </message>
    <message>
        <source>Qt Help Project File</source>
        <translation>Projektový soubor s nápovědou Qt</translation>
    </message>
    <message>
        <source>Qt Help Collection Project File</source>
        <translation>Projektový sbírkový soubor s nápovědou Qt</translation>
    </message>
    <message>
        <source>The specified file %1 already exist.

Do you want to remove it?</source>
        <translation>Zadaný soubor %1 již existuje.

Chcete jej odstranit?</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Odstranit</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
</context>
<context>
    <name>PathPage</name>
    <message>
        <source>Form</source>
        <translation>Formulář</translation>
    </message>
    <message>
        <source>File filters:</source>
        <translation>Souborové filtry:</translation>
    </message>
    <message>
        <source>Documentation source file paths:</source>
        <translation>Cesty ke zdrojovým souborům s dokumentací:</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Přidat</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Odstranit</translation>
    </message>
    <message>
        <source>Source File Paths</source>
        <translation>Cesty ke zdrojovým souborům</translation>
    </message>
    <message>
        <source>Specify the paths where the sources files are located. By default, all files in those directories matched by the file filter will be included.</source>
        <translation>Zadejte cesty k místům, v nichž jsou uloženy zdrojové soubory. Ve výchozím nastavení budou zahrnuty všechny soubory v těchto adresářích odpovídající podle souborového filtru.</translation>
    </message>
    <message>
        <source>Source File Path</source>
        <translation>Cesta ke zdrojovému souboru</translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <source>Add Documentation</source>
        <translation>Přidat dokumentaci</translation>
    </message>
    <message>
        <source>Qt Compressed Help Files (*.qch)</source>
        <translation>Stlačené soubory s nápovědou (*.qch)</translation>
    </message>
    <message>
        <source>The specified file is not a valid Qt Help File!</source>
        <translation>Zadaný soubor není platným souborem nápovědy ke Qt.</translation>
    </message>
    <message>
        <source>The namespace %1 is already registered!</source>
        <translation>Jmenný prostor %1 je již zaznamenám!</translation>
    </message>
    <message>
        <source>Remove Documentation</source>
        <translation>Odstranit dokumentaci</translation>
    </message>
    <message>
        <source>Some documents currently opened in Assistant reference the documentation you are attempting to remove. Removing the documentation will close those documents.</source>
        <translation>Některé v současnosti otevřené dokumenty pocházejí z dokumentace, kterou se právě pokoušíte odstranit. Při odstraňování budou zavřeny.</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Use custom settings</source>
        <translation>Použít nastavení stanovená uživatelem</translation>
    </message>
</context>
<context>
    <name>PreferencesDialogClass</name>
    <message>
        <source>Preferences</source>
        <translation>Nastavení</translation>
    </message>
    <message>
        <source>Fonts</source>
        <translation>Písma</translation>
    </message>
    <message>
        <source>Font settings:</source>
        <translation>Nastavení písem:</translation>
    </message>
    <message>
        <source>Browser</source>
        <translation>Prohlížeč</translation>
    </message>
    <message>
        <source>Application</source>
        <translation>Program</translation>
    </message>
    <message>
        <source>Filters</source>
        <translation>Filtr</translation>
    </message>
    <message>
        <source>Filter:</source>
        <translation>Filtr:</translation>
    </message>
    <message>
        <source>Attributes:</source>
        <translation>Vlastnosti:</translation>
    </message>
    <message>
        <source>1</source>
        <translation>1</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Přidat</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Odstranit</translation>
    </message>
    <message>
        <source>Documentation</source>
        <translation>Dokumentace</translation>
    </message>
    <message>
        <source>Registered Documentation:</source>
        <translation>Zaznamenaná dokumentace:</translation>
    </message>
    <message>
        <source>Add...</source>
        <translation>Přidat...</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Volby</translation>
    </message>
    <message>
        <source>Current Page</source>
        <translation>Nynější strana</translation>
    </message>
    <message>
        <source>Restore to default</source>
        <translation>Obnovit výchozí nastavení</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation>Začáteční stránka</translation>
    </message>
    <message>
        <source>On help start:</source>
        <translation>Na začátek nápovědy:</translation>
    </message>
    <message>
        <source>Show my home page</source>
        <translation>Ukázat moji domovskou stránku</translation>
    </message>
    <message>
        <source>Show a blank page</source>
        <translation>Ukázat prázdnou stránku</translation>
    </message>
    <message>
        <source>Show my tabs from last session</source>
        <translation>Ukázat mé karty z posledního sezení</translation>
    </message>
    <message>
        <source>Blank Page</source>
        <translation>Prázdná strana</translation>
    </message>
    <message>
        <source>Appearance</source>
        <translation>Vzhled</translation>
    </message>
    <message>
        <source>Show tabs for each individual page</source>
        <translation>Ukázat karty pro každou jednotlivou stranu</translation>
    </message>
</context>
<context>
    <name>QCollectionGenerator</name>
    <message>
        <source>Unknown token at line %1.</source>
        <translation>Neznámé klíčové slovo na řádku %1.</translation>
    </message>
    <message>
        <source>Unknown token at line %1. Expected &quot;QtHelpCollectionProject&quot;.</source>
        <translation>Neznámé klíčové slovo na řádku %1. Očekáván &quot;QtHelpCollectionProject&quot;.</translation>
    </message>
    <message>
        <source>Missing end tags.</source>
        <translation>Chybí zavírající prvky.</translation>
    </message>
    <message>
        <source>Missing input or output file for help file generation.</source>
        <translation>Chybí některé pro vytvoření souboru s nápovědou potřebné vstupní nebo výstupní soubory.</translation>
    </message>
    <message>
        <source>Missing output file name.</source>
        <translation>Nebyl zadán žádný název pro výstupní soubor.</translation>
    </message>
    <message>
        <source>Qt Collection Generator version 1.0 (Qt %1)
</source>
        <translation>Qt Collection Generator verze 1.0 (Qt %1)
</translation>
    </message>
    <message>
        <source>Missing collection config file.</source>
        <translation>Soubor s nastavením potřebný pro sbírku chybí.</translation>
    </message>
    <message>
        <source>
Usage:

qcollectiongenerator &lt;collection-config-file&gt; [options]

  -o &lt;collection-file&gt;   Generates a collection file
                         called &lt;collection-file&gt;. If
                         this option is not specified
                         a default name will be used.
  -v                     Displays the version of
                         qcollectiongenerator.

</source>
        <translation>Použití:

qcollectiongenerator &lt;collection-config-file&gt; [volby]

  -o &lt;collection-file&gt;   Vytvoří soubor se sbírkou
                         nazvaný &lt;collection-file&gt;. Pokud
                         tato volba není stanovena
                         použije se výchozí název.
  -v                     Zobrazí verzi
                         qcollectiongeneratoru.

</translation>
    </message>
    <message>
        <source>Could not open %1.
</source>
        <translation>Nepodařilo se otevřít %1.
</translation>
    </message>
    <message>
        <source>Reading collection config file...
</source>
        <translation>Čte se soubor s nastavením pro sbírku...
</translation>
    </message>
    <message>
        <source>Collection config file error: %1
</source>
        <translation>Chyba v souboru s nastavením pro sbírku: %1
</translation>
    </message>
    <message>
        <source>Generating help for %1...
</source>
        <translation>Vytváří se nápověda pro %1...
</translation>
    </message>
    <message>
        <source>Creating collection file...
</source>
        <translation>Vytváří se sbírkový soubor...
</translation>
    </message>
    <message>
        <source>The file %1 cannot be overwritten.
</source>
        <translation>Soubor %1 nelze přepsat.
</translation>
    </message>
    <message>
        <source>Cannot open %1.
</source>
        <translation>Nelze otevřít %1.
</translation>
    </message>
    <message>
        <source>Cannot open referenced image file %1.
</source>
        <translation>Nelze otevřít odkazovaný obrázkový soubor %1.
</translation>
    </message>
</context>
<context>
    <name>QHelpGenerator</name>
    <message>
        <source>Missing output file name.</source>
        <translation>Nebyl zadán žádný název pro výstupní soubor.</translation>
    </message>
    <message>
        <source>Qt Help Generator version 1.0 (Qt %1)
</source>
        <translation>Qt Collection Generator verze 1.0 (Qt %1)
</translation>
    </message>
    <message>
        <source>Missing Qt help project file.</source>
        <translation>Chybí projektový soubor s nápovědou Qt.</translation>
    </message>
    <message>
        <source>
Usage:

qhelpgenerator &lt;help-project-file&gt; [options]

  -o &lt;compressed-file&gt;   Generates a Qt compressed help
                         file called &lt;compressed-file&gt;.
                         If this option is not specified
                         a default name will be used.
  -c                     Checks whether all links in HTML files
                         point to files in this help project.
  -v                     Displays the version of 
                         qhelpgenerator.

</source>
        <translation>Použití:

qhelpgenerator &lt;help-project-file&gt; [volby]

  -o &lt;compressed-file&gt;   Vytvoří zabalenou nápovědu
                         nazvanou &lt;compressed-file&gt;. Pokud
                         tato volba není stanovena
                         použije se výchozí název.
  -c                    Ověří, zda všechny odkazy v souborech HTML
                         ukazují na soubory v tomto projektu nápovědy.
  -v                    Zobrazí verzi 
                         qhelpgenerator.

</translation>
    </message>
    <message>
        <source>Could not open %1.
</source>
        <translation>Nepodařilo se otevřít %1.
</translation>
    </message>
    <message>
        <source>Could not create output directory: %1
</source>
        <translation>Nepodařilo se vytvořit výstupní adresář: %1
</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>The specified collection file does not exist!</source>
        <translation type="obsolete">Zadaný sbírkový soubor nelze najít!</translation>
    </message>
    <message>
        <source>Missing collection file!</source>
        <translation type="obsolete">Chybějící sbírkový soubor!</translation>
    </message>
    <message>
        <source>Invalid URL!</source>
        <translation type="obsolete">Neplatné URL!</translation>
    </message>
    <message>
        <source>Missing URL!</source>
        <translation type="obsolete">Chybějící URL!</translation>
    </message>
    <message>
        <source>Unknown widget: %1</source>
        <translation type="obsolete">Neznámý prvek: %1</translation>
    </message>
    <message>
        <source>Missing widget!</source>
        <translation type="obsolete">Chybějící prvek!</translation>
    </message>
    <message>
        <source>The specified Qt help file does not exist!</source>
        <translation type="obsolete">Zadaný soubor s nápovědou ke Qt nelze najít!</translation>
    </message>
    <message>
        <source>Missing help file!</source>
        <translation type="obsolete">Chybějící soubor s nápovědou!</translation>
    </message>
    <message>
        <source>Missing filter argument!</source>
        <translation type="obsolete">Chybějící argument pro filtr!</translation>
    </message>
    <message>
        <source>Unknown option: %1</source>
        <translation type="obsolete">Neznámá volba: %1</translation>
    </message>
    <message>
        <source>Qt Assistant</source>
        <translation type="obsolete">Qt Assistant</translation>
    </message>
    <message>
        <source>Could not register documentation file
%1

Reason:
%2</source>
        <translation type="obsolete">Soubor s dokumentací %1 nelze zaznamenat

Důvod:
%2</translation>
    </message>
    <message>
        <source>Documentation successfully registered.</source>
        <translation type="obsolete">Dokumentace byla úspěšně zaznamenána.</translation>
    </message>
    <message>
        <source>Could not unregister documentation file
%1

Reason:
%2</source>
        <translation type="obsolete">Zaznamenání souboru s dokumentací %1 nelze zrušit

Grund:
%2</translation>
    </message>
    <message>
        <source>Documentation successfully unregistered.</source>
        <translation type="obsolete">Dokumentace byla úspěšně odstraněna.</translation>
    </message>
    <message>
        <source>Cannot load sqlite database driver!</source>
        <translation type="obsolete">Databázový ovladač pro SQLite nelze nahrát!</translation>
    </message>
    <message>
        <source>The specified collection file could not be read!</source>
        <translation type="obsolete">Zadaný sbírkový soubor nelze přečíst!</translation>
    </message>
</context>
<context>
    <name>RemoteControl</name>
    <message>
        <source>Debugging Remote Control</source>
        <translation>Ladí se dálkové ovládání</translation>
    </message>
    <message>
        <source>Received Command: %1 %2</source>
        <translation>Přijatý příkaz: %1 : %2</translation>
    </message>
</context>
<context>
    <name>SearchWidget</name>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;Kopírovat</translation>
    </message>
    <message>
        <source>Copy &amp;Link Location</source>
        <translation>&amp;Kopírovat adresu odkazu</translation>
    </message>
    <message>
        <source>Open Link in New Tab</source>
        <translation>Otevřít odkaz v nové kartě</translation>
    </message>
    <message>
        <source>Select All</source>
        <translation>Vybrat vše</translation>
    </message>
</context>
<context>
    <name>TabBar</name>
    <message>
        <source>(Untitled)</source>
        <translation>(Bez názvu)</translation>
    </message>
    <message>
        <source>New &amp;Tab</source>
        <translation>Nová &amp;karta</translation>
    </message>
    <message>
        <source>&amp;Close Tab</source>
        <translation>&amp;Zavřít kartu</translation>
    </message>
    <message>
        <source>Close Other Tabs</source>
        <translation>Zavřít jiné karty</translation>
    </message>
    <message>
        <source>Add Bookmark for this Page...</source>
        <translation>Přidat záložku pro tuto stranu...</translation>
    </message>
</context>
<context>
    <name>TopicChooser</name>
    <message>
        <source>Choose a topic for &lt;b&gt;%1&lt;/b&gt;:</source>
        <translation>Vyberte námět pro &lt;b&gt;%1&lt;/b&gt;:</translation>
    </message>
    <message>
        <source>Choose Topic</source>
        <translation>Vybrat námět</translation>
    </message>
    <message>
        <source>&amp;Topics</source>
        <translation>&amp;Náměty</translation>
    </message>
    <message>
        <source>&amp;Display</source>
        <translation>&amp;Zobrazit</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Zavřít</translation>
    </message>
</context>
</TS>
